## Template registry (BETA)

Template registry is a storage API for versioned prompts. It allows you to store and retrieve templates from local storage.
Currently, it supports storing templates in a JSON file, but it can be extended to support other storage backends.

### Usage

Coming soon.